@@ -32,7 +32,7 @@
 
 /**
  * SECTION:languagemanager
- * @Short_description: Object which provides access to #GtkSourceLanguage<!-- -->s
+ * @Short_description: Object which provides access to GtkSourceLanguages
  * @Title: GtkSourceLanguageManager
  * @See_also: #GtkSourceLanguage
  *
@@ -65,8 +65,7 @@ struct _GtkSourceLanguageManagerPrivate
 	gchar          **ids; /* Cache the IDs of the available languages */
 };
 
-G_DEFINE_TYPE (GtkSourceLanguageManager, gtk_source_language_manager, G_TYPE_OBJECT)
-
+G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceLanguageManager, gtk_source_language_manager, G_TYPE_OBJECT)
 
 static void
 gtk_source_language_manager_set_property (GObject 	*object,
@@ -162,15 +161,12 @@ gtk_source_language_manager_class_init (GtkSourceLanguageManagerClass *klass)
 							       "languages"),
 							     G_TYPE_STRV,
 							     G_PARAM_READABLE));
-
-	g_type_class_add_private (object_class, sizeof(GtkSourceLanguageManagerPrivate));
 }
 
 static void
 gtk_source_language_manager_init (GtkSourceLanguageManager *lm)
 {
-	lm->priv = G_TYPE_INSTANCE_GET_PRIVATE (lm, GTK_SOURCE_TYPE_LANGUAGE_MANAGER,
-						GtkSourceLanguageManagerPrivate);
+	lm->priv = gtk_source_language_manager_get_instance_private (lm);
 	lm->priv->language_ids = NULL;
 	lm->priv->ids = NULL;
 	lm->priv->lang_dirs = NULL;
@@ -578,13 +574,13 @@ pick_lang_for_mime_type (GtkSourceLanguageManager *lm,
 	if (alt_filename != NULL)
 	{
 		GSList *langs;
-		
+
 		langs = pick_langs_for_filename (lm, alt_filename);
-		
+
 		if (langs != NULL)
 			lang = GTK_SOURCE_LANGUAGE (langs->data);
 	}
-	
+
 	if (lang == NULL && mime_type != NULL)
 		lang = pick_lang_for_mime_type_real (lm, mime_type);
 
@@ -669,46 +665,46 @@ gtk_source_language_manager_guess_language (GtkSourceLanguageManager *lm,
 		if (content_type != NULL)
 		{
 			GSList *l;
-			
+
 			for (l = langs; l != NULL; l = g_slist_next (l))
 			{
 				gchar **mime_types, **gptr;
-				
+
 				lang = GTK_SOURCE_LANGUAGE (l->data);
 				mime_types = gtk_source_language_get_mime_types (lang);
-				
+
 				for (gptr = mime_types; gptr != NULL && *gptr != NULL; gptr++)
 				{
 					gchar *content;
-					
+
 					content = g_content_type_from_mime_type (*gptr);
-					
+
 					if (content != NULL && g_content_type_is_a (content_type, content))
 					{
 						if (!g_content_type_equals (content_type, content))
 						{
 							GtkSourceLanguage *mimelang;
-							
+
 							mimelang = pick_lang_for_mime_type (lm, content_type);
-							
+
 							if (mimelang != NULL)
 								lang = mimelang;
 						}
-						
+
 						g_strfreev (mime_types);
 						g_slist_free (langs);
 						g_free (content);
-						
+
 						return lang;
 					}
 					g_free (content);
 				}
-				
+
 				g_strfreev (mime_types);
 			}
 		}
 		lang = GTK_SOURCE_LANGUAGE (langs->data);
-		
+
 		g_slist_free (langs);
 	}
 	/* No glob match */
